@@ -77,7 +77,7 @@ class ConfigGenerationCommand(object):
             self.log.debug(i + " : " + str(getattr(args, i)))
         self.log.debug("Namespace : end.")
 
-        configfile = self.config.prog_name + ".cfg"
+        configfile = os.path.expanduser('~/.' + self.config.prog_name + '.cfg')
         if args.output:
             configfile = args.output
 
@@ -98,24 +98,17 @@ class ConfigAutoCompteCommand(object):
         print """
 This program is comptible with the python autocomplete program called
 argcomplete.\n
-You can either install this program using:
-- sudo apt-get install python-argcomplete
-or
-- sudo apt-get install python-pip
-- sudo pip install argcomplete
-
-Once this program is installed, you have two configuration options:
+This program should already be installed, but in some case, you have to
+configure  it :
 
 1. Global configuration
     All programs compliant with argcomplete will be detected automatically
     with bash >= 4.2.
-    This won't work with Debian Squeeze for example.
     - sudo activate-global-python-argcomplete
 
 2. Specific configuration
     Manually include the following command ind your ~/.bashrc:
-    - eval "$(register-python-argcomplete linshare_cli_user.py)"
-
+    - eval "$(register-python-argcomplete linsharecli.py)"
 
 
 """
@@ -130,8 +123,10 @@ class DocumentsListCommand(DefaultCommand):
         super(DocumentsListCommand, self).__call__(args)
 
         json_obj = self.ls.documents.list()
-        d_format = "{name:60s}{creationDate:30s}{uuid:30s}"
+        d_format = u"{name:60s}{creationDate:30s}{uuid:40s}{description}"
         self.format_date(json_obj, 'creationDate')
+        from operator import itemgetter
+        json_obj = sorted(json_obj, reverse = True, key=itemgetter("creationDate"))
         self.print_list(json_obj, d_format, "Documents")
 
 
@@ -144,7 +139,7 @@ class DocumentsUploadCommand(DefaultCommand):
         super(DocumentsUploadCommand, self).__call__(args)
 
         for file_path in args.files:
-            json_obj = self.ls.documents.upload(file_path)
+            json_obj = self.ls.documents.upload(file_path, args.description)
             if json_obj:
                 json_obj['time'] = self.ls.last_req_time
                 self.log.info(
@@ -177,6 +172,33 @@ class DocumentsDownloadCommand(DefaultCommand):
             v.get('uuid') for v in json_obj if v.get('uuid').startswith(prefix))
 
 
+# -----------------------------------------------------------------------------
+class DocumentsDeleteCommand(DefaultCommand):
+
+    def __call__(self, args):
+        super(DocumentsDeleteCommand, self).__call__(args)
+
+        for uuid in args.uuids:
+            try:
+                json_obj = self.ls.documents.delete(uuid)
+                file_name = json_obj.get('name')
+                self.log.info(
+                    "The file '" + file_name +
+                    "' (" + uuid + ")" +
+                    " was deleted. (" + self.ls.last_req_time + "s)")
+            except urllib2.HTTPError as ex:
+                print "Error : "
+                print ex
+                return
+
+    def complete(self, args,  prefix):
+        super(DocumentsDeleteCommand, self).__call__(args)
+
+        json_obj = self.ls.documents.list()
+        return (
+            v.get('uuid') for v in json_obj if v.get('uuid').startswith(prefix))
+
+
 # -----------------------------------------------------------------------------
 class DocumentsUploadAndSharingCommand(DefaultCommand):
 
@@ -222,7 +244,7 @@ class ReceivedSharesListCommand(DefaultCommand):
         super(ReceivedSharesListCommand, self).__call__(args)
 
         json_obj = self.ls.rshares.list()
-        d_format = "{name:60s}{creationDate:30s}{uuid:30s}"
+        d_format = u"{name:60s}{creationDate:30s}{uuid:30s}"
         self.format_date(json_obj, 'creationDate')
         self.print_list(json_obj, d_format, "Received Shares")
 
@@ -299,7 +321,7 @@ class ThreadsListCommand(DefaultCommand):
         super(ThreadsListCommand, self).__call__(args)
 
         json_obj = self.ls.threads.list()
-        d_format = "{name:60s}{creationDate:30s}{uuid:30s}"
+        d_format = u"{name:60s}{creationDate:30s}{uuid:30s}"
         #self.pretty_json(json_obj)
         self.format_date(json_obj, 'creationDate')
         self.print_list(json_obj, d_format, "Threads")
@@ -316,7 +338,7 @@ class ThreadMembersListCommand(DefaultCommand):
 
         json_obj = self.ls.thread_members.list(args.uuid)
 
-        d_format = "{firstName:11s}{lastName:10s}{admin:<7}{readonly:<9}{id}"
+        d_format = u"{firstName:11s}{lastName:10s}{admin:<7}{readonly:<9}{id}"
         #self.pretty_json(json_obj)
         self.print_list(json_obj, d_format, "Thread members")
 
@@ -337,7 +359,7 @@ class UsersListCommand(DefaultCommand):
         super(UsersListCommand, self).__call__(args)
 
         json_obj = self.ls.users.list()
-        d_format = "{firstName:11s}{lastName:10s}{domain:<20}{mail}"
+        d_format = u"{firstName:11s}{lastName:10s}{domain:<20}{mail}"
         #print "%(firstName)-10s %(lastName)-10s\t %(domain)s %(mail)s" % f
         #self.pretty_json(json_obj)
         self.print_list(json_obj, d_format, "Users")
@@ -354,6 +376,8 @@ def add_document_parser(subparsers, name, desc):
     parser_tmp2 = subparsers2.add_parser('upload',
                                          help="upload documents to linshare")
     parser_tmp2.set_defaults(__func__=DocumentsUploadCommand())
+    parser_tmp2.add_argument('--desc', action="store", dest="description",
+                             required=False, help="Optional description.")
     parser_tmp2.add_argument('files', nargs='+')
 
     parser_tmp2 = subparsers2.add_parser('upshare',
@@ -363,12 +387,19 @@ def add_document_parser(subparsers, name, desc):
     parser_tmp2.add_argument('-m', '--mail', action="append", dest="mails",
                              required=True, help="Recipient mails.")
 
+
     parser_tmp2 = subparsers2.add_parser(
         'download',
         help="download documents from linshare")
     parser_tmp2.set_defaults(__func__=DocumentsDownloadCommand())
     parser_tmp2.add_argument('uuids', nargs='+').completer = DefaultCompleter()
 
+    parser_tmp2 = subparsers2.add_parser(
+        'delete',
+        help="delete documents from linshare")
+    parser_tmp2.set_defaults(__func__=DocumentsDeleteCommand())
+    parser_tmp2.add_argument('uuids', nargs='+').completer = DefaultCompleter()
+
     parser_tmp2 = subparsers2.add_parser(
         'list',
         help="list documents from linshare")
